Module cli_def

Module cli_def 

Central CLI struct definition — shared between the binary (main.rs) and the unit tests inside the library modules (completions, man).

Structs

CliApp
The rusmes command-line application parser.

Enums

BackupAction
Backup sub-actions.
BackupFormat
Backup format selection.
ColorChoice
Color output preference.
Commands
Top-level subcommands.
CompressionType
Compression algorithm selection.
MailboxAction
Mailbox management sub-actions.
QueueAction
Queue management sub-actions.
RestoreAction
Restore sub-actions.
UserAction
User management sub-actions.

Functions

should_color
Determine whether ANSI colors should be emitted given the user’s choice and whether stdout is currently a TTY.