should_color

Function should_color 

pub fn should_color(choice: ColorChoice, is_tty: bool) -> bool
Determine whether ANSI colors should be emitted given the user’s choice and whether stdout is currently a TTY.

This is a pure function that can be tested without side-effects.

choiceis_ttyresult
Alwaysanytrue
Neveranyfalse
Autotruetrue
Autofalsefalse