run

Function run 

pub fn run<A>() -> Result<()>
where A: CommandFactory,
Write roff-formatted man page for the given CLI application to stdout.

The output can be piped directly into man -l - for immediate viewing, or stored in a system man directory (e.g. /usr/local/share/man/man1/).

Errors

Returns an error if writing to stdout fails.